<?php

namespace Drupal\sitemorse_lite\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\sitemorse_lite\Sitemorse\Checker;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;

/**
 * Class CheckController.
 */
class CheckController implements ContainerInjectionInterface {

  /**
   * The sitemorse checker service.
   *
   * @var \Drupal\sitemorse_lite\Sitemorse\Checker
   */
  private $checker;

  /**
   * CheckController constructor.
   */
  public function __construct(Checker $checker) {
    $this->checker = $checker;
  }

  /**
   * Run sitemorse check for a given URL.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   JSON response for client.
   */
  public function checkUrl(Request $request) {
    $url = $request->query->get('url');

    if (empty($url)) {
      throw new BadRequestHttpException();
    }

    $result = $this->checker->checkUrl($url);

    return new JsonResponse(['url' => $result->getResultUrl()]);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('sitemorse_lite.checker')
    );
  }

}
