<?php

namespace Drupal\sitemorse_lite\Sitemorse;

use Drupal\Core\Extension\ModuleHandlerInterface;
use SCIClient;

/**
 * Encapsulates various Sitemorse checking procedures called from Drupal.
 */
class Checker implements CheckerInterface {

  /**
   * The SCI Client PHP library.
   *
   * @var SCIClient
   */
  protected $client;

  /**
   * ModuleHandler service for invoking hooks.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  private $moduleHandler;

  /**
   * Constructor - set up PHP client library.
   */
  public function __construct(ModuleHandlerInterface $moduleHandler, SCIClient $client) {
    $this->moduleHandler = $moduleHandler;
    $this->client = $client;
  }

  /**
   * {@inheritdoc}
   */
  public function checkUrl($url): Results {
    $response = $this->client->performTest($url);
    $results = Results::fromTestResults($response);

    $this->moduleHandler->invokeAll('sitemorse_lite_results', [$url, $results]);

    return $results;
  }

}
